#include <Adafruit_SPIFlash.h>
#include <bluefruit.h>

// set service uuid (little endian format)
uint8_t Uuid128[16] =
{
  0xF0, 0xEF, 0xDE, 0xCD, 0xBC, 0xAB, 0x9A, 0x89,
  0x78, 0x67, 0x56, 0x45, 0x34, 0x23, 0x12, 0x01
}; 
BLEUuid uuid = BLEUuid(Uuid128);


// initialize advertised data packet
uint8_t user_data[3] = {0, 0, 0};

// initialize counter of advertised packet
uint8_t counter = 0;


void startAdv(void)
{  
  // Set GAP ADV Flag, optional but a standard deployed by most users 
  Bluefruit.Advertising.addFlags(BLE_GAP_ADV_FLAGS_LE_ONLY_GENERAL_DISC_MODE);

  // Construction of data packet to be advertised
  if (counter == 0xFF)
  {counter = 0;}
  else 
  {counter = counter + 1;}
  user_data[0] = 0x59;     // little endian format for first and second entry
  user_data[1] = 0x00;     // (00-59) means Nordic Semi
  user_data[2] = counter;  // third entry increments with each advertising cycle
  Bluefruit.Advertising.addData(BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA, user_data, sizeof(user_data)/sizeof(user_data[0]));
  
  // append service uuid to the packet
  Bluefruit.Advertising.addData(BLE_GAP_AD_TYPE_128BIT_SERVICE_UUID_COMPLETE, Uuid128, sizeof(Uuid128)/sizeof(Uuid128[0]));

  Bluefruit.Advertising.restartOnDisconnect(true);
  Bluefruit.Advertising.setIntervalMS(100, 100);    // in unit of ms
  Bluefruit.Advertising.setFastTimeout(5);          // number of seconds in fast mode
  Bluefruit.Advertising.start(5);                   // stop advertising after 5 seconds
  //Bluefruit.Advertising.clearData();    
}


void setup()
{
  // Shut down unused QSPI flash memory
  Adafruit_FlashTransport_QSPI flashTransport;
  flashTransport.begin();
  flashTransport.runCommand(0xB9);
  flashTransport.end();

  // Enable DC-DC converter
  NRF_POWER->DCDCEN = 1;
  
  Bluefruit.begin();
  Bluefruit.autoConnLed(false); // turn off LED to save power
  Bluefruit.setTxPower(4);    // Check bluefruit.h for supported values
}

void loop()
{
  startAdv();
  __WFE();
  __WFI();
  delay(10000);  // advertising period = 10s
  Bluefruit.Advertising.clearData();  // refresh advertised data for each cycle
}
